@@ -1,8 +1,9 @@
 
 from .client import Client
+from .dbapi import connect
 
 
-VERSION = (0, 1, 2)
+VERSION = (0, 1, 3)
 __version__ = '.'.join(str(x) for x in VERSION)
 
-__all__ = ['Client']
+__all__ = ['Client', 'connect']
